==> muroard_0.1.7.orig.tar.gz: muroard-0.1.7/para.h <==
//para.h:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
 *
 *  This file is part of RoarD,
 *  a sound server daemon for using the RoarAudio protocol.
 *  See README for details.
 *
 *  This file is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 3
 *  or (at your option) any later version as published by
 *  the Free Software Foundation.
 *
 *  RoarAudio is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 *
 */

/*
 * This header contains the declarations for all run-time options/parameters
 */

#ifndef _MUROARD_PARA_H_
#define _MUROARD_PARA_H_

/*********************************************************/
/* audio config                                          */
/*********************************************************/

int muroard_g_sa_rate;
int muroard_g_sa_channels;

/*********************************************************/
/* mixer config                                          */
/*********************************************************/

size_t muroard_g_abuffer_size;

/*********************************************************/
/* network config                                        */
/*********************************************************/

#ifdef MUROARD_FEATURE_SOCKET_LISTEN
int muroard_g_listen_socket;
#endif

#endif

//ll

==> muroard_0.1.9.orig.tar.gz: muroard-0.1.9/para.h <==
//para.h:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
 *
 *  This file is part of RoarD,
 *  a sound server daemon for using the RoarAudio protocol.
 *  See README for details.
 *
 *  This file is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 3
 *  or (at your option) any later version as published by
 *  the Free Software Foundation.
 *
 *  RoarAudio is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 *
 */

/*
 * This header contains the declarations for all run-time options/parameters
 */

#ifndef _MUROARD_PARA_H_
#define _MUROARD_PARA_H_

/*********************************************************/
/* audio config                                          */
/*********************************************************/

int muroard_g_sa_rate;
int muroard_g_sa_channels;

/*********************************************************/
/* mixer config                                          */
/*********************************************************/

size_t muroard_g_abuffer_size;

/*********************************************************/
/* network config                                        */
/*********************************************************/

#ifdef MUROARD_FEATURE_SOCKET_LISTEN
muroard_handle_t muroard_g_listen_socket;
#endif
#ifdef MUROARD_FEATURE_SOCKET_LISTEN_SOCKTYPE
int muroard_g_listen_type;
#endif

#endif

//ll
